This function creates an object of class predictParam that can be used to
predict molecular fingerprints and compound identifications using
CSI:FingerID and CANOPUS.
CSI:FIngerID identifies the structure of a molecule by predicting its molecular fingerprint and using this fingerprint to search in a molecular structure database.
CANOPUS (Dührkop et al.) predicts the presense/absense of more than 2500 compound classes. CANOPUS predicts these classes based solely on MS/MS data and without requiring database information. This means it can identify a class even if no molecular structure of that class exists in the molecular structure database.
Arguments
- useScoreThreshold
logicalwhether to use a soft threshold to be applied to only compute FingerPrints for promising formula candidates. Enabling is highly recommended. Default isTRUE.- alwaysPredictHighRefMatches
logicalwether to predict FingerPrint/Classes&Structure for formulas candidates with reference spectrum similarity >Sirius.minReferenceMatchScoreToInjectno matter which score threshold rules apply. Default isFALSE.
Note
For more information, see the Sirius documentation.