This set of functions provides tools for managing databases in Sirius. These include listing available databases, retrieving database information, deleting databases, and creating new databases from files.
List the databases that are searchable by Sirius for spectral matching.
Retrieve detailed information about a specific database.
Delete a database from Sirius.
Create a new database in Sirius from specified files.
Arguments
- sirius
A
Siriusobject representing the Sirius connection.- databaseId
A
character(1)string specifying the new database ID.- files
A
charactervector of file paths to add to the database.- location
A
character(1)string specifying the location for the database. Defaults to the current working directory.