This function is to set up the parameter for matching to spectra databases. This needs to be run first. Spectral library matching is performed using the cosine score with squared peak intensities, ignoring the precursor peak.
Note that spectral library matches are added as annotations to CSI:FingerID results and do not influence the ranking of structure candidates.
Arguments
- spectraSearchDBs
charactervector of the databases to search. The default isc("BIO", "massbank"). Other values can be found by runninglistDatabases().- peakDeviationPpm
numericMaximum allowed mass deviation in ppm for matching peaks.- precursorDeviationPpm
numericMaximum allowed mass deviation in ppm for matching the precursor. If not specified, the same value as for the peaks is used.- scoring
characterThe scoring function to use. Possible values areMODIFIED_COSINE,GAUSSIAN,INTENSITY. The default isMODIFIED_COSINE.
Note
For more information, see the Sirius documentation.
Examples
# Example of setting up the parameters for spectra matching
param <- spectraMatchingParam(spectraSearchDBs = c("BIO", "massbank"),
peakDeviationPpm = 10,
precursorDeviationPpm = 10,
scoring = "MODIFIED_COSINE")