This function creates an object of class structureDbSearchParam that can
be used to configure the structure database search in Sirius. The object can
be passed to the runSirius function to perform the structure database
search.
By default, SIRIUS searches for molecular structures in a biomolecule structure database. It can also search in the (extremely large) PubChem database or in custom “suspect databases” provided by the user.
Arguments
- structureSearchDbs
charactervector, specifying the id of the databases to search for structures. Default isc("BIO", "massbank"). If expansive search is enabled this database selection will be expanded to PubChem if not high confidence hit was found in the selected databases. The available databases can be found by runninglistDatabases().logical, specifying whether to tag structures with lipid class estimated by El Gordo. The lipid class will only be available if El Gordo predicts that the MS/MS is a lipid spectrum. If this parameter is set toFALSEEl Gordo will still be executed and e.g. improve the fragmentation tree, but the matching structure candidates will not be tagged if they match lipid class.- expansiveSearchConfidenceMode
character(1), specifying the confidence mode for expansive search. Possible values are"APPROXIMATE","EXACT","OFF". Defaults to"APPROXIMATE".
Note
For more information, see the Sirius documentation.
Examples
# Example of setting up the parameters for structure database search
param <- structureDbSearchParam(
structureSearchDbs = c("BIO", "massbank"),
tagStructuresWithLipidClass = TRUE,
expansiveSearchConfidenceMode = "APPROXIMATE")